@@ -10,7 +10,7 @@ has _source_file_registry => sub { Sentry::SourceFileRegistry->new };
 has _home                 => sub { Mojo::Home->new->detect };
 
 sub _is_in_app ($self) {
-  return $self->filename !~ /\.cpan/
+  return $self->filename !~ /\.cpan\//
     && index($self->filename, $self->_home) > -1;
 }
 
